pub enum GameError {
    Running(Error),
    RawMode(Box<dyn Error>),
    TerminalMode(Error),
    TerminalExecute(Error),
}
These are different reasons a game could end.

Variants

Running(Error)

An error occured while running the application.

RawMode(Box<dyn Error>)

An error occured trying to enable RawMode on this terminal.

TerminalMode(Error)

An error occured while creating a new terminal or showing the cursor.

TerminalExecute(Error)

An error occured trying to execute commands on the terminal.